# Gaze 智能视频云服务

Gaze 实时视频分析服务平台整合私有云的计算能力和物联网设备(如摄像头)的数据，在端(Edge)提供可扩展、可伸缩的视频分析能力。

# 简介
当今社会到处都是摄像头。据统计，互联网上85%的数据量是视频数据，且仍在飞速增长。当人们再谈论大数据和物联网设备的时候，大数据主要指视频数据，物联网设备主要指摄像头。但海量数据是否已经得到充分的挖掘和利用呢? 答案是受限于视频分析能力，这些大数据就像是暗物质，远未得到有效利用。

按一个低清摄像头每天视频积累数据量是1.5G，高清的话是15G。如果一个商场安装了一百个摄像头，这些数据量是T级别的。如果把这些数据传到公有云，这是一种攻击，而非使用。因此在公有云上进行视频分析将是得不偿失的，但和私有云却是一个完美的结合。

鉴于此，我们提出 Gaze 来整合私有云的计算能力和物联网设备(如摄像头)的数据。在端(Edge)提供可扩展、可伸缩的视频分析能力。对于开发者来说，如果有视频分析的需求，可以通过简单几行语句，基于我们事先搭好的“积木”，将一些视频流转化成事件流，通过event hub、卡夫卡（Kafka）传给下游。

# 系统架构

![image](https://github.com/foamliu/Gaze/raw/master/images/architecture.svg?sanitize=true)

# 数据流图

![image](https://github.com/foamliu/Gaze/raw/master/images/dataflow.svg?sanitize=true)

# 快速上手

```bash
$ python demo.py
```


